@@ -259,6 +259,8 @@ class Firecrest:
 
         if status_code == 401:
             raise fe.UnauthorizedException(responses)
+        elif status_code == 404:
+            raise fe.NotFound(responses)
         elif status_code >= 400:
             raise fe.FirecrestException(responses)
         elif status_code != expected_status_code:
@@ -543,6 +545,32 @@ class Firecrest:
         )
         return self._json_response([resp], 200)["output"]
 
+    def stat(self, machine, target_path, dereference=False):
+        """Uses the stat linux application to determine the status of a file on the machine's filesystem.
+
+        :param machine: the machine name where the filesystem belongs to
+        :type machine: string
+        :param target_path: the absolute target path
+        :type target_path: string
+        :param dereference: follow link (default False)
+        :type dereference: boolean, optional
+        :calls: GET `/utilities/stat`
+        :rtype: string
+        """
+        url = f"{self._firecrest_url}/utilities/stat"
+        headers = {
+            "Authorization": f"Bearer {self._authorization.get_access_token()}",
+            "X-Machine-Name": machine,
+        }
+        params = {"targetPath": target_path}
+        if dereference:
+            params["dereference"] = dereference
+
+        resp = requests.get(
+            url=url, headers=headers, params=params, verify=self._verify
+        )
+        return self._json_response([resp], 200)["output"]
+
     def symlink(self, machine, target_path, link_path):
         """Creates a symbolic link.
 
@@ -704,7 +732,10 @@ class Firecrest:
         # FIXME This needs to be added as an endpoint in FirecREST,
         # now it's making a guess and it could be wrong.
         try:
-            decoded = jwt.decode(self._authorization.get_access_token(), verify=False)
+            decoded = jwt.decode(
+                self._authorization.get_access_token(),
+                options={"verify_signature": False},
+            )
             try:
                 if self._sa_role in decoded["realm_access"]["roles"]:
                     clientId = decoded["clientId"]
@@ -820,9 +851,14 @@ class Firecrest:
         self._current_method_requests = []
         jobids = [str(j) for j in jobs]
         json_response = self._acct_request(machine, jobids, start_time, end_time)
-        return self._poll_tasks(
+        res = self._poll_tasks(
             json_response["task_id"], "200", itertools.cycle([1, 5, 10])
         )
+        # When there is no job in the sacct output firecrest will return an empty dictionary instead of list
+        if isinstance(res, dict):
+            return list(res.values())
+        else:
+            return res
 
     def poll_active(self, machine, jobs=[]):
         """Retrieves information about active jobs.
